Crate kcr_inference_kubedl_io

Crate kcr_inference_kubedl_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the inference.kubedl.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

inference.kubedl.io/v1alpha1

  • ElasticBatchJob

Modules

v1alpha1